InvalidLanguageVersion class abstract

An invalid language version.

Stored in a Package when the original language version string was invalid and a onError handler was passed to the parser which did not throw for that error. The caller which provided the non-throwing onError handler should be prepared to encounter invalid values.

Implemented types
Implementers
Available extensions
Annotations
  • @sealed

Constructors

InvalidLanguageVersion()

Properties

hashCode int
The hash code for this object.
no setteroverride
major int
The value -1 for an invalid language version.
no setteroverride
minor int
The value -1 for an invalid language version.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

compareTo(LanguageVersion other) int
Compares language versions.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
The original invalid version string.
override

Operators

operator <(LanguageVersion other) bool

Available on LanguageVersion, provided by the LanguageVersionRelationalOperators extension

Whether this language version is less than other.
operator <=(LanguageVersion other) bool

Available on LanguageVersion, provided by the LanguageVersionRelationalOperators extension

Whether this language version is less than or equal to other.
operator ==(Object other) bool
An invalid language version is only equal to itself.
override
operator >(LanguageVersion other) bool

Available on LanguageVersion, provided by the LanguageVersionRelationalOperators extension

Whether this language version is greater than other.
operator >=(LanguageVersion other) bool

Available on LanguageVersion, provided by the LanguageVersionRelationalOperators extension

Whether this language version is greater than or equal to other.